/**
 * The data model for manually adapted equivalence sets.
 * 
 * <h3>Current equivalence model</h3>
 * <p>
 * This model is subject to be enhanced!
 * </p>
 * <p>
 * This package contains a model for normalisations that will be created by the
 * user and associated to a collation set. The normalization is used to compare
 * tokens of the witnesses to collate, as described below.
 * <p>
 * Each {@linkplain info.textgrid.lab.collatex.model.equivalences.Equivalences
 * normalization} contains a list of
 * {@linkplain info.textgrid.lab.collatex.model.equivalences.Equivalence
 * equivalences}. Each equivalence contains a list of
 * {@linkplain info.textgrid.lab.collatex.model.equivalences.EToken tokens} that
 * are to be considered equal. Equivalences can be
 * {@linkplain info.textgrid.lab.collatex.model.equivalences.Equivalence#isLocal()
 * local or global}, for local equivalences, the respective tokens' positions
 * are taken in consideration.
 * <h4>Comparison algorithm</h4>
 * <p>
 * The comparison algorithm's result is equivalent to the following:
 * </p>
 * <p>
 * Let <var>w</var> and <var>v</var> be tokens to be compared.
 * </p>
 * <p>
 * If <var>w</var>'s normalized content equals <var>v</var>'s normalized
 * content, the tokens are considered equivalent. Otherwise, we extract the set
 * of equivalences matching <var>w</var>, <var>E(w)</var> as follows: For each
 * equivalence <var>e</var> in the whole equivalence set, we check whether the
 * set of tokens of <var>e</var> contains at least one token <var>t</var> that
 * is considered equal to <var>w</var>. If the equivalence <var>e</var> is
 * global, <var>t</var> and <var>w</var> match if their respective normalized
 * contents are equal. If <var>e</var> is local, additionally the
 * {@linkplain info.textgrid.lab.collatex.model.equivalences.EToken#getPosition()
 * positions} of <var>t</var> and <var>w</var> must be equal.
 * </p>
 * <p>
 * A similar set of equivalences is calculated for <var>v</var>. If and only if
 * the intersection of <var>E(v)</var> and <var>E(w)</var> is non-empty,
 * <var>w</var> and <var>v</var> are considered equivalent.
 * </p>
 * 
 * @see info.textgrid.lab.collatex.process.EquivalenceSetTokenComparator
 */
@XmlSchema(namespace = "http://textgrid.info/namespaces/collation/tokenModel",
elementFormDefault = XmlNsForm.QUALIFIED)
@XmlSeeAlso({ TokenIndex.class, Position.class })
package info.textgrid.lab.collatex.model.equivalences;

import javax.xml.bind.annotation.XmlNsForm;
import javax.xml.bind.annotation.XmlSchema;
import javax.xml.bind.annotation.XmlSeeAlso;

